pub type CoalesceTable = SideTable<CoalesceChain>;Expand description
Every or-coalescing chain’s recorded typing, keyed at the chain root
(see the module doc for why not per step).
Aliased Type
pub struct CoalesceTable { /* private fields */ }pub type CoalesceTable = SideTable<CoalesceChain>;Every or-coalescing chain’s recorded typing, keyed at the chain root
(see the module doc for why not per step).
pub struct CoalesceTable { /* private fields */ }